@@ -3,6 +3,8 @@ Design <- setRefClass("Design",
                     fields = list(method = 'character',
                                   criteria = 'character',
                                   criteria_estimator = 'character',
+                                  classify = 'numeric',
+                                  classify_alpha = 'numeric',
                                   min_SEM = 'numeric',
                                   met_SEM = 'logical',
                                   min_items = 'integer',
@@ -17,11 +19,17 @@ Design <- setRefClass("Design",
                                   preCAT_method = 'character',
                                   CAT_criteria = 'character',
                                   CAT_method = 'character',
-                                  max_time = 'numeric'),
+                                  max_time = 'numeric',
+                                  use_content = 'logical',
+                                  content = 'factor',
+                                  content_prop = 'numeric',
+                                  content_prop_empirical = 'numeric',
+                                  numerical_info = 'logical'),
                     
                     methods = list(
                         initialize = function(method, criteria, nfact, design,
                                               start_item, preCAT, nitems, exposure){
+                            numerical_info <<- FALSE
                             method <<- method
                             criteria <<- criteria
                             criteria_estimator <<- 'MAP'
@@ -56,7 +64,22 @@ Design <- setRefClass("Design",
                             preCAT_nitems <<- 0L
                             KL_delta <<- 0.1
                             max_time <<- Inf
+                            use_content <<- FALSE
+                            content_prop_empirical <<- 1
+                            classify <<- NaN
+                            classify_alpha <<- .05
                             if(length(design)){
+                                if(!is.null(design$content)){
+                                    use_content <<- TRUE
+                                    content <<- factor(design$content)
+                                    if(!mirt:::closeEnough(sum(design$content_prop)-1, -1e-6, 1e-6))
+                                        stop('content_prop does not sum to 1')
+                                    tmp <- design$content_prop
+                                    tmp <- tmp[match(names(table(content)), names(tmp))]
+                                    content_prop <<- tmp
+                                    tmp[1L:length(tmp)] <- 0
+                                    content_prop_empirical <<- tmp
+                                }
                                 if(!is.null(design$max_time))
                                     max_time <<- design$max_time
                                 if(!is.null(design$KL_delta))
@@ -69,7 +92,18 @@ Design <- setRefClass("Design",
                                     min_items <<- as.integer(design$min_items)
                                 if(!is.null(design$max_items))
                                     max_items <<- as.integer(design$max_items)
+                                if(!is.null(design$numerical_info))
+                                    numerical_info <<- design$numerical_info
+                                if(!is.null(design$classify))
+                                    classify <<- design$classify
+                                if(!is.null(design$classify_CI)){
+                                    if(design$classify_CI > 1 || design$classify_CI < 0)
+                                        stop('classify_CI criteria must be between 0 and 1')
+                                    classify_alpha <<- (1 - design$classify_CI)/2
+                                }
                             }
+                            if(use_content && criteria == 'seq')
+                                stop('content designs are not supported for seq criteria')
                             if(!mirt:::closeEnough(sum(Wrule_weights)-1, -1e-6, 1e-6))
                                 stop('Wrule_weights does not sum to 1')
                             if(length(min_SEM) != 1L && length(min_SEM) != nfact)
@@ -99,8 +133,13 @@ Design$methods(
         if(MCE$person$score){
             if(nanswered >= min_items){
                 diff <- MCE$person$thetas_SE_history[nrow(MCE$person$thetas_SE_history), ]
-                met_SEM <<- diff < min_SEM
-                if(all(met_SEM)) stop_now <<- TRUE
+                if(!is.nan(classify[1L])){
+                    z <- -abs(MCE$person$thetas - classify) / diff
+                    if(all(z < qnorm(classify_alpha))) stop_now <<- TRUE
+                } else {
+                    met_SEM <<- diff < min_SEM
+                    if(all(met_SEM)) stop_now <<- TRUE
+                }
             }
         }
         if(nanswered == max_items) stop_now <<- TRUE
