@@ -6,55 +6,67 @@ server <- function(input, output) {
     
     dynamicUi <- reactive({
         
+        click <- input$Next
+        
         #first page, ask for demographics, etc
-        if(input$Next == 0L){
+        if(click == 0L){
             return(MCE$shinyGUI$firstpage)
         }
         
-        if(input$Next == 1L){
+        #skip demographics page?
+        if(!length(MCE$shinyGUI$demographics)) click <- click + 1L
+        
+        if(click == 1L){
             return(MCE$shinyGUI$demographics)
         }
         
         #store demographic results
-        if(input$Next == 2L){
+        if(click == 2L){
             tmp <- list()
             for(tag in MCE$shinyGUI$demographic_inputIDs)
                 tmp[[length(tmp) + 1L]] <- input[[tag]]
             names(tmp) <- MCE$shinyGUI$demographic_inputIDs
             MCE$person$field("demographics", as.data.frame(tmp))
+            if(!is.null(MCE$last_demographics))
+                MCE$person$demographics <- MCE$last_demographics
+            if(MCE$shinyGUI$temp_file != '')
+                saveRDS(MCE$person, MCE$shinyGUI$temp_file)
             return(list(h5("Click \'Next\' to start the survey.")))
         }
         
-        if(input$Next == 3L) MCE$start_time <- proc.time()[3L]
+        if(click == 3L) MCE$start_time <- proc.time()[3L]
         
-        itemclick <- input$Next - 3L
+        itemclick <- sum(!is.na(MCE$person$items_answered))
         
         # run survey
-        if(input$Next > 2L && !MCE$design$stop_now){
+        if(click > 2L && !MCE$design$stop_now){
             if(itemclick >= 1L){
                 pick <- MCE$person$items_answered[itemclick]
                 name <- MCE$test$itemnames[pick]
                 ip <- input[[name]]
-                MCE$person$raw_responses[pick] <- MCE$person$responses[pick] <- 
-                    which(MCE$test$item_options[[pick]] %in% ip) - 1L
-                if(!is.na(MCE$test$item_answers[[pick]]) && 
-                       MCE$test$item_class[pick] != 'nestlogit')
-                    MCE$person$responses[pick] <- as.integer(ip == MCE$test$item_answers[[pick]])
-                
-                MCE$person$item_time[pick] <- proc.time()[3L] - MCE$start_time - 
-                    sum(MCE$person$item_time)
-                
-                #update Thetas
-                MCE$person$Update.thetas()
-                if(itemclick > MCE$design$preCAT_nitems)
-                    MCE$design$Update.stop_now()
+                if(!is.null(ip)){
+                    MCE$person$raw_responses[pick] <- MCE$person$responses[pick] <- 
+                        which(MCE$test$item_options[[pick]] %in% ip) - 1L
+                    if(!is.na(MCE$test$item_answers[[pick]]) && 
+                           MCE$test$item_class[pick] != 'nestlogit')
+                        MCE$person$responses[pick] <- as.integer(ip == MCE$test$item_answers[[pick]])
+                    
+                    MCE$person$item_time[pick] <- proc.time()[3L] - MCE$start_time - 
+                        sum(MCE$person$item_time)
+                    
+                    #update Thetas
+                    MCE$person$Update.thetas()
+                    if(MCE$shinyGUI$temp_file != '')
+                        saveRDS(MCE$person, MCE$shinyGUI$temp_file)
+                    if(itemclick > MCE$design$preCAT_nitems)
+                        MCE$design$Update.stop_now()
+                }
             } 
             
             MCE$design$Next.stage(item=itemclick)
             
             if(!MCE$design$stop_now){
-                item <- findNextCATItem(person=MCE$person, test=MCE$test, 
-                                        lastitem=itemclick, criteria=MCE$design$criteria)
+                item <- findNextCATItem(person=MCE$person, test=MCE$test, design=MCE$design)
                 MCE$person$items_answered[itemclick+1L] <- item
                 return(MCE$shinyGUI$questions[[item]])
             }
@@ -63,6 +75,8 @@ server <- function(input, output) {
         #last page
         if(!MCE$STOP){
             MCE$STOP <- TRUE
+            if(MCE$shinyGUI$temp_file != '')
+                saveRDS(MCE$person, MCE$shinyGUI$temp_file)
             return(MCE$shinyGUI$lastpage)
         } else {
             stopApp()
@@ -72,11 +86,15 @@ server <- function(input, output) {
     }) 
         
     output$item_stem <- renderImage({
+        
+        click <- input$Next
+        if(click > 0L)
+            if(!length(MCE$shinyGUI$demographics)) click <- click + 1L
             
         if(!MCE$STOP){
-            if(input$Next > 2L && (input$Next-2L) < MCE$test$length){
+            if(click > 2L && (click-2L) < MCE$test$length){
                 empty <- is.na(MCE$shinyGUI$stem_locations[[
-                    MCE$person$items_answered[[input$Next-2L]]]])
+                    MCE$person$items_answered[[click-2L]]]])
             } else empty <- TRUE
         } else empty <- TRUE
         
@@ -90,7 +108,7 @@ server <- function(input, output) {
                         height = 1,
                         alt = ""))
         } else {
-            return(list(src = MCE$shinyGUI$stem_locations[[input$Next-2L]]))
+            return(list(src = MCE$shinyGUI$stem_locations[[click-2L]]))
         }
         
     }, deleteFile = FALSE)
